@@ -10,11 +10,11 @@ Module::Starter - a simple starter kit for any module
 
 =head1 VERSION
 
-Version 1.58
+Version 1.59
 
 =cut
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 =head1 SYNOPSIS
 
@@ -129,9 +129,9 @@ You can also look for information at:
 
 =over 4
 
-=item * Source code at Google Code
+=item * Source code at GitHub
 
-L<http://code.google.com/p/module-starter/>
+L<https://github.com/xsawyerx/module-starter>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
