@@ -9,7 +9,7 @@ Module::Starter::App - the code behind the command line program
 use warnings;
 use strict;
 
-our $VERSION = '1.57';
+our $VERSION = '1.59';
 
 use Path::Class;
 use Getopt::Long;
@@ -17,7 +17,7 @@ use Pod::Usage;
 use Carp qw( croak );
 
 sub _config_file {
-    my $class     = shift;
+    my $self      = shift;
     my $configdir = $ENV{'MODULE_STARTER_DIR'} || '';
 
     if ( !$configdir && $ENV{'HOME'} ) {
@@ -29,12 +29,11 @@ sub _config_file {
 
 
 sub _config_read {
-    my $class = shift;
-
-    my $filename = $class->_config_file;
+    my $self = shift;
 
+    my $filename = $self->_config_file;
     return unless -e $filename;
-
+    
     open( my $config_file, '<', $filename )
         or die "couldn't open config file $filename: $!\n";
 
@@ -44,13 +43,16 @@ sub _config_read {
         next if /\A\s*\Z/sm;
         if (/\A(\w+):\s*(.+)\Z/sm) { $config{$1} = $2; }
     }
+    
+    return $self->_config_multi_process(%config);
+}
 
-    # The options that accept multiple arguments must be set to an
-    # arrayref
-    $config{plugins} = [ split /(?:\s*,\s*|\s+)/, $config{plugins} ] if $config{plugins};
-    $config{builder} = [ split /(?:\s*,\s*|\s+)/, $config{builder} ] if $config{builder};
+sub _config_multi_process {
+    my ( $self, %config ) = @_;
 
-    foreach my $key ( qw( plugins modules builder ) ){
+    # The options that accept multiple arguments must be set to an arrayref
+    foreach my $key (qw( builder ignores_type modules plugins )) {
+        $config{$key} = [ split /(?:\s*,\s*|\s+)/, (ref $config{$key} ? join(',', @{$config{$key}}) : $config{$key}) ] if $config{$key};
         $config{$key} = [] unless exists $config{$key};
     }
 
@@ -71,6 +73,7 @@ sub _process_command_line {
         'distro=s'   => \$config{distro},
         'module=s@'  => \$config{modules},
         'builder=s@' => \$config{builder},
+        'ignores=s@' => \$config{ignores_type},
         eumm         => sub { push @{$config{builder}}, 'ExtUtils::MakeMaker' },
         mb           => sub { push @{$config{builder}}, 'Module::Build' },
         mi           => sub { push @{$config{builder}}, 'Module::Install' },
@@ -78,6 +81,7 @@ sub _process_command_line {
         'author=s'   => \$config{author},
         'email=s'    => \$config{email},
         'license=s'  => \$config{license},
+        'minperl=s'  => \$config{minperl},
         force        => \$config{force},
         verbose      => \$config{verbose},
         version      => sub {
@@ -112,10 +116,11 @@ to change.
 =cut
 
 sub run {
-    my $class  = shift;
-    my %config = $class->_config_read;
+    my $self   = shift;
+    my %config = $self->_config_read;
 
-    %config = $class->_process_command_line(%config);
+    %config = $self->_process_command_line(%config);
+    %config = $self->_config_multi_process(%config);
 
     eval "require $config{class};";
     croak "Could not load starter class $config{class}: $@" if $@;
